/**
 * HMsweep - software to measure frequnecy responses with the sound card and a
 * Hameg digital storage oscilloscope
 *         
 * Copyright (C) 2007 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General
 * Public License along with this program; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin St,
 * Fifth Floor, Boston, MA 02110, USA
 *
 * Contact the author via
 * LSto@opppf.de
 * http://opppf.de/HMsweep/
 */
#ifndef SINEGEN_H
#define SINEGEN_H

#include <alsa/asoundlib.h>
#include <pthread.h>

/**
 * Struct identifying a sine generator.
 */
typedef struct
{
  double f;
  snd_pcm_t * alsa;
  pthread_t thread;
} sinegen_alsa_t;


/**
 * Start sine generator with frequency f.
 *
 * alsa		alsa deviece for output
 * f		frequency in Hz, must be <= 22050 Hz
 * return: sinegen handle, NULL on error
 */
sinegen_alsa_t * sinegen_alsa_start( const char * device, double f );


/**
 * Stop sine generator.
 *
 * sg	singe generator
 */
void sinegen_alsa_stop( sinegen_alsa_t * sg );


#endif
