/**
 * HMsweep - software to measure frequnecy responses with the sound card and a
 * Hameg digital storage oscilloscope
 *         
 * Copyright (C) 2016 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General
 * Public License along with this program; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin St,
 * Fifth Floor, Boston, MA 02110, USA
 *
 * Contact the author via
 * LSto@opppf.de
 * http://opppf.de/HMsweep/
 */
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <string.h>
#include "sinegen_hm.h"

/* debugging */
#define debugc(x) fprintf( stderr, "%s=%c\n", #x, (x) )
#define debugi(x) fprintf( stderr, "%s=%d\n", #x, (x) )
#define debugd(x) fprintf( stderr, "%s=%f\n", #x, (x) )

/**
 * write string to file
 *
 * fd	file descriptor to write to
 * s	string to write
 * return: -1 on error, else number of bytes sent
 */
int write_str( int fd, const char * s )
{
    char cr[] = { 0x0d, 0x00 };
    int len = strlen( s );

    if ( write( fd, s, len ) != len  )
	return -1;
    if ( write( fd, cr, 1 ) != 1 )
	return -1;
    return len+1;
}


/* **********************************************************************
 * api functions
 * ********************************************************************** */

/**
 * Start sine generator with frequency f.
 *
 * device	serial deviece for output
 * f		frequency in Hz
 * return: sinegen handle, NULL on error
 */
sinegen_hm_t * sinegen_hm_start( const char * device, double f )
{
    sinegen_hm_t * sg = malloc( sizeof(sinegen_hm_t) );
    int fd;
    char buf[13]; // "FRQ:10123456\0"

    if ( f > 10e6 ) // 10 MHz
	f = 10e6;
    sg->fd = fd = open232( device, 9600, "8n2", XONXOFF, RAW );
    if ( fd < 0 )
	return NULL;
    sprintf( buf, "FRQ:%.0f", f );
    write_str( fd, "SIN" ); // sine wave
    write_str( fd, "CTM" ); // free running
    write_str( fd, "SW0" ); // no wobbling
    write_str( fd, "AM0" ); // no AM
    write_str( fd, "FSK0" );// no FSK
    write_str( fd, "PSK0" );// no PSK
    write_str( fd, buf );
    write_str( fd, "OT1" );
    return sg;
}


/**
 * Stop sine generator.
 *
 * sg	singe generator
 */
void sinegen_hm_stop( sinegen_hm_t * sg )
{
    write_str( sg->fd, "OT0" );
    close( sg->fd );
    free( sg );
}



